﻿using System.Diagnostics;
using System.Xml.Linq;

namespace Kolory.Model
{
    static class DAL //Data Access Layer
    {
        private static string ścieżkaPliku =
            Path.Combine(
                Environment.GetFolderPath(Environment.SpecialFolder.UserProfile),
                "ustawienia.xml");

        private static IFormatProvider fp = System.Globalization.CultureInfo.InvariantCulture;

        public static Stan CzytajZPlikuXml()
        {
            try
            {
                XDocument xml = XDocument.Load(ścieżkaPliku);
                XElement? root = xml.Root;
                if (root != null)
                {
                    byte r = byte.Parse(root.Element("r").Value, fp);
                    byte g = byte.Parse(root.Element("g").Value, fp);
                    byte b = byte.Parse(root.Element("b").Value, fp);
                    return new Stan() { R = r, G = g, B = b };
                }
                else throw new NullReferenceException("Nie można odczytać pliku XML");
            }
            catch
            {
                return new Stan();
            }
        }

        public static void ZapiszDoPlikuXml(this Stan stan)
        {
            XDocument xml = new XDocument(
                new XDeclaration("1.0", "utf-8", "yes"),
                new XComment("Data zapisu: " + DateTime.Now.ToString()),
                new XElement("ustawienia",
                    new XElement("r", stan.R.ToString(fp)),
                    new XElement("g", stan.G.ToString(fp)),
                    new XElement("b", stan.B.ToString(fp))
                )
            );

            try
            {
                xml.Save(ścieżkaPliku);
            }
            catch (Exception exc)
            {
                Debug.WriteLine($"Nie udało się zapisać stanu aplikacji. Błąd: {exc.Message}");
            }
        }
    }
}
